@@ -890,7 +890,7 @@ if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == TRUE)
   cluster->faces = TRUE;
 button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "voronoi_button_atoms");
 if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == TRUE)
-  cluster->dots = TRUE;
+  cluster->n_dots = TRUE;
 
 /********************************
  * get borders combo box option *
