@@ -21,11 +21,6 @@
 #include "gamgi_mesa_select.h"
 #include "gamgi_io_token.h"
 
-void gamgi_gtk_orbital_select (GtkWidget *widget, void *data)
-{
-printf ("handle orbital select\n");
-}
-
 void gamgi_gtk_arrow_select (GtkWidget *widget, void *data)
 {
 printf ("handle arrow select\n");
