@@ -53,13 +53,13 @@
  * enumerations: GAMGI property, GTK combo *
  *******************************************/
 
-enum { STATIC_NAME, STATIC_TYPE, STATIC_ATOM, STATIC_STRUCTURE,
+enum { STATIC_NAME, STATIC_REFERENCE, STATIC_ATOM, STATIC_STRUCTURE,
 STATIC_FILTER, STATIC_VISIBLE, STATIC_COPLANAR, STATIC_ELEMENT, STATIC_NUMBER,
 STATIC_TRANSLATION_X, STATIC_TRANSLATION_Y, STATIC_TRANSLATION_Z,
 STATIC_ROTATION_E1, STATIC_ROTATION_E2, STATIC_ROTATION_E3, STATIC_STYLE,
 STATIC_RED, STATIC_GREEN, STATIC_BLUE, STATIC_SCALE };
 
-enum { STATIC_TYPE_CONTAINER, STATIC_TYPE_POLYTOPE, STATIC_TYPE_LOCAL };
+enum { STATIC_REFERENCE_CONTAINER, STATIC_REFERENCE_POLYTOPE, STATIC_REFERENCE_LOCAL };
 enum { STATIC_STRUCTURE_COPY, STATIC_STRUCTURE_LINK, STATIC_STRUCTURE_NONE };
 enum { STATIC_FILTER_CLASS, STATIC_FILTER_CHILD, STATIC_FILTER_IDENTICAL,
 STATIC_FILTER_NONE };
@@ -72,7 +72,7 @@ gamgi_bool local;
 gamgi_bool new[STATIC_SCALE + 1];
 char name[GAMGI_ENGINE_TOKEN];
 gamgi_atom *atom;
-gamgi_enum type, structure, filter;
+gamgi_enum reference, structure, filter;
 double visible, coplanar, radius;
 int element, number;
 gamgi_bool translation_absolute, rotation_absolute;
@@ -314,11 +314,11 @@ if (gamgi_io_token_check (name) == FALSE) return GAMGI_ENGINE_GROUP;
  * otherwise select which object to select *
  *******************************************/
 
-combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_type");
+combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_reference");
 row = gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
-if (row == STATIC_TYPE_CONTAINER) return GAMGI_ENGINE_GROUP;
-if (row == STATIC_TYPE_POLYTOPE) return GAMGI_ENGINE_ATOM;
-if (row == STATIC_TYPE_LOCAL) return GAMGI_ENGINE_GROUP;
+if (row == STATIC_REFERENCE_CONTAINER) return GAMGI_ENGINE_GROUP;
+if (row == STATIC_REFERENCE_POLYTOPE) return GAMGI_ENGINE_ATOM;
+if (row == STATIC_REFERENCE_LOCAL) return GAMGI_ENGINE_GROUP;
 
 /********************************
  * this case should never occur *
@@ -506,7 +506,7 @@ entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_scale");
 gtk_entry_set_text (GTK_ENTRY (entry), "");
 }
 
-static void static_type (GtkWidget *widget, void *data)
+static void static_reference (GtkWidget *widget, void *data)
 {
 gamgi_window *window = GAMGI_CAST_WINDOW data;
 GtkWidget *dialog = window->dialog0;
@@ -521,11 +521,11 @@ int row;
  * get data *
  ************/
 
-combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_type");
+combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_reference");
 row = gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
 
 vbox = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "vbox_view");
-if (row == STATIC_TYPE_CONTAINER)
+if (row == STATIC_REFERENCE_CONTAINER)
   gtk_widget_hide (vbox);
 else
   { gtk_widget_show (vbox); static_start_view (window); }
@@ -533,7 +533,7 @@ else
 combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_color");
 sensitive = (gamgi_bool *) g_object_get_data (G_OBJECT (dialog), "sensitive_color");
 vbox = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "vbox_scope");
-if (row == STATIC_TYPE_POLYTOPE)
+if (row == STATIC_REFERENCE_POLYTOPE)
   {
   label = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "label_central");
   gtk_widget_set_sensitive (label, TRUE);
@@ -563,7 +563,7 @@ else
   }
 
 vbox = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "vbox_position");
-if (row == STATIC_TYPE_LOCAL)
+if (row == STATIC_REFERENCE_LOCAL)
   { gtk_widget_show (vbox); static_start_position (window); }
 else
   gtk_widget_hide (vbox);
@@ -610,13 +610,13 @@ GtkWidget *entry;
 entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_group");
 gtk_entry_set_text (GTK_ENTRY (entry), "");
 
-/********************
- * reset group type *
- ********************/
+/*************************
+ * reset group reference *
+ *************************/
 
-combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_type");
-gtk_combo_box_set_active (GTK_COMBO_BOX (combo), STATIC_TYPE_LOCAL);
-static_type (NULL, window);
+combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_reference");
+gtk_combo_box_set_active (GTK_COMBO_BOX (combo), STATIC_REFERENCE_LOCAL);
+static_reference (NULL, window);
 
 /***********************
  * reset Position data *
@@ -667,7 +667,7 @@ GtkWidget *dialog = window->dialog0;
 GtkWidget *label, *button;
 gamgi_bool *sensitive;
 
-sensitive = (gamgi_bool *) g_object_get_data (G_OBJECT (dialog), "sensitive_type");
+sensitive = (gamgi_bool *) g_object_get_data (G_OBJECT (dialog), "sensitive_reference");
 
 label = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "label_group");
 button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_list");
@@ -678,8 +678,8 @@ if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == FALSE)
    **********************************/
 
   gtk_label_set_text (GTK_LABEL (label), "Group");
-  sensitive[STATIC_TYPE_CONTAINER] = TRUE;
-  sensitive[STATIC_TYPE_POLYTOPE] = TRUE;
+  sensitive[STATIC_REFERENCE_CONTAINER] = TRUE;
+  sensitive[STATIC_REFERENCE_POLYTOPE] = TRUE;
   static_absolute (dialog);
   }
 else
@@ -689,8 +689,8 @@ else
    **********************************************/
 
   gtk_label_set_text (GTK_LABEL (label), "Name");
-  sensitive[STATIC_TYPE_CONTAINER] = FALSE;
-  sensitive[STATIC_TYPE_POLYTOPE] = FALSE;
+  sensitive[STATIC_REFERENCE_CONTAINER] = FALSE;
+  sensitive[STATIC_REFERENCE_POLYTOPE] = FALSE;
   static_reset (window);
   static_relative (dialog);
   }
@@ -708,14 +708,14 @@ char token[GAMGI_ENGINE_TOKEN];
 const char *name;
 int row;
 
-/******************
- * get group type *
- ******************/
+/***********************
+ * get group reference *
+ ***********************/
 
-cache.new[STATIC_TYPE] = FALSE;
-combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_type");
-cache.type = gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
-if (cache.type != STATIC_TYPE_LOCAL) cache.new[STATIC_TYPE] = TRUE;
+cache.new[STATIC_REFERENCE] = FALSE;
+combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_reference");
+cache.reference = gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
+if (cache.reference != STATIC_REFERENCE_LOCAL) cache.new[STATIC_REFERENCE] = TRUE;
 
 /********************
  * get central atom *
@@ -815,11 +815,11 @@ if (visible == TRUE && gamgi_io_token_check (name) == TRUE)
  * r is the distance from central to the nearest neighbour           *
  *********************************************************************/
 
-cache.number = 0; cache.radius = 0.0;
+cache.number = 0; cache.radius = DBL_MAX;
 cache.new[STATIC_NUMBER] = FALSE;
 entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_number");
 name = gtk_entry_get_text (GTK_ENTRY (entry));
-if (visible == TRUE)
+if (visible == TRUE && gamgi_io_token_check (name) == TRUE)
   {
   cache.new[STATIC_NUMBER] = TRUE;
   button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_number");
@@ -1106,7 +1106,7 @@ if (cache.new[STATIC_SCALE] == TRUE) scale = cache.scale;
  * check data compatibility *
  ****************************/
 
-if (cache.type == STATIC_TYPE_POLYTOPE)
+if (cache.reference == STATIC_REFERENCE_POLYTOPE)
   {
   /**********************
    * check central atom *
@@ -1167,7 +1167,7 @@ if (cache.type == STATIC_TYPE_POLYTOPE)
 if (cache.local == TRUE)
   gamgi_gtk_history_update (window->layer, window->layer->undo, GAMGI_ENGINE_UNDO);
 
-if (cache.type != STATIC_TYPE_LOCAL)
+if (cache.reference != STATIC_REFERENCE_LOCAL)
   {
   /**************************************************
    * reset group: free arrays, remove child objects *
@@ -1196,7 +1196,7 @@ if (cache.type != STATIC_TYPE_LOCAL)
   group->faces = FALSE;
   }
 
-if (cache.type == STATIC_TYPE_CONTAINER)
+if (cache.reference == STATIC_REFERENCE_CONTAINER)
   {
   /****************
    * set new data *
@@ -1228,7 +1228,7 @@ if (cache.type == STATIC_TYPE_CONTAINER)
   gtk_entry_set_text (GTK_ENTRY (entry), string);
   }
 
-if (cache.type == STATIC_TYPE_POLYTOPE)
+if (cache.reference == STATIC_REFERENCE_POLYTOPE)
   {
   /********************************************************
    * When the polytope algorithm fails to produce a valid *
@@ -1300,7 +1300,7 @@ if (cache.type == STATIC_TYPE_POLYTOPE)
     gamgi_engine_remove_group (group_old);
 
     dialog = gamgi_gtk_dialog_report_create (text,
-    "Group Create Polytope", GAMGI_GTK_GROUP_CREATE_POLYTOPE, window);
+    "Group Modify Polytope", GAMGI_GTK_GROUP_MODIFY_POLYTOPE, window);
     gtk_widget_show (dialog);
     }
 
@@ -1315,7 +1315,7 @@ if (cache.type == STATIC_TYPE_POLYTOPE)
     }
   }
 
-if (cache.type == STATIC_TYPE_LOCAL)
+if (cache.reference == STATIC_REFERENCE_LOCAL)
   {
   strcpy (group->object.name, name);
 
@@ -1448,7 +1448,7 @@ if (focus == TRUE)
  *****************************************/
 
 gtk_widget_queue_draw (window->area);
-if (cache.type == STATIC_TYPE_LOCAL)
+if (cache.reference == STATIC_REFERENCE_LOCAL)
   static_reset (window);
 }
 
@@ -1500,9 +1500,9 @@ gtk_widget_set_size_request (notebook, size.width, size.height);
  * hide pages AFTER measuring notebook size *
  ********************************************/
 
-combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_type");
-gtk_combo_box_set_active (GTK_COMBO_BOX (combo), STATIC_TYPE_LOCAL);
-static_type (NULL, window);
+combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_reference");
+gtk_combo_box_set_active (GTK_COMBO_BOX (combo), STATIC_REFERENCE_LOCAL);
+static_reference (NULL, window);
 }
 
 static void static_press (gamgi_object *object, void *data)
@@ -1536,9 +1536,9 @@ if (class == GAMGI_ENGINE_GROUP)
    * set Type combo to Local *
    ***************************/
 
-  combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_type");
-  gtk_combo_box_set_active (GTK_COMBO_BOX (combo), STATIC_TYPE_LOCAL);
-  static_type (NULL, window);
+  combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_reference");
+  gtk_combo_box_set_active (GTK_COMBO_BOX (combo), STATIC_REFERENCE_LOCAL);
+  static_reference (NULL, window);
 
   /***********************************
    * set Group position, orientation *
@@ -1776,8 +1776,8 @@ gtk_widget_show (label);
 combo = gtk_combo_box_new ();
 gtk_box_pack_start (GTK_BOX (hbox_left), combo, FALSE, FALSE, 0);
 g_signal_connect (combo, "changed",
-G_CALLBACK (static_type), window);
-g_object_set_data (G_OBJECT (dialog), "combo_type", combo);
+G_CALLBACK (static_reference), window);
+g_object_set_data (G_OBJECT (dialog), "combo_reference", combo);
 gtk_widget_show (combo);
 
 store = gtk_list_store_new (1, G_TYPE_STRING);
@@ -1795,7 +1795,7 @@ gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (combo), renderer, FALSE);
 gtk_cell_layout_set_attributes (GTK_CELL_LAYOUT (combo), renderer, "text", 0, NULL);
 
 sensitive = gamgi_gtk_dialog_sensitive_create (3);
-g_object_set_data (G_OBJECT (dialog), "sensitive_type", sensitive);
+g_object_set_data (G_OBJECT (dialog), "sensitive_reference", sensitive);
 gtk_cell_layout_set_cell_data_func (GTK_CELL_LAYOUT (combo),
 renderer, gamgi_gtk_dialog_sensitive_scan, sensitive, free);
 
