@@ -187,7 +187,6 @@ else
   gtk_widget_set_sensitive (entry_blue, FALSE);
   }
 
-static_axes (NULL, window);
 }
 
 static void static_style (GtkWidget *widget, void *data)
@@ -331,6 +330,33 @@ static_l (NULL, window);
 
 static void static_reset (gamgi_window *window)
 {
+GtkWidget *dialog = window->dialog0;
+GtkWidget *entry;
+char token[GAMGI_ENGINE_TOKEN];
+
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_x");
+sprintf (token, "%.*f", gamgi->gamgi->length, GAMGI_CHEM_ORBITAL_X);
+gtk_entry_set_text (GTK_ENTRY (entry), token);
+
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_y");
+sprintf (token, "%.*f", gamgi->gamgi->length, GAMGI_CHEM_ORBITAL_Y);
+gtk_entry_set_text (GTK_ENTRY (entry), token);
+
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_z");
+sprintf (token, "%.*f", gamgi->gamgi->length, GAMGI_CHEM_ORBITAL_Z);
+gtk_entry_set_text (GTK_ENTRY (entry), token);
+
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_e1");
+sprintf (token, "%.*f", gamgi->gamgi->angle, GAMGI_CHEM_ORBITAL_E1);
+gtk_entry_set_text (GTK_ENTRY (entry), token);
+
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_e2");
+sprintf (token, "%.*f", gamgi->gamgi->angle, GAMGI_CHEM_ORBITAL_E2);
+gtk_entry_set_text (GTK_ENTRY (entry), token);
+
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_e3");
+sprintf (token, "%.*f", gamgi->gamgi->angle, GAMGI_CHEM_ORBITAL_E3);
+gtk_entry_set_text (GTK_ENTRY (entry), token);
 }
 
 static void static_ok (GtkWidget *widget, void *data)
@@ -393,7 +419,7 @@ entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_density");
 name = gtk_entry_get_text (GTK_ENTRY (entry));
 if (gamgi_io_token_double_scan (name, &orbital->density, 0.0, 1.0) == FALSE)
   {
-  gamgi_gtk_dialog_message_create ("Error", "Invalid probability density threshold", window);
+  gamgi_gtk_dialog_message_create ("Error", "Invalid probability density", window);
   gamgi_engine_remove_orbital (orbital);
   return;
   }
@@ -701,7 +727,7 @@ gtk_entry_set_text (GTK_ENTRY (entry), token);
  ********************/
 
 combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_style");
-gtk_combo_box_set_active (GTK_COMBO_BOX (combo), GAMGI_MESA_SOLID - 1);
+gtk_combo_box_set_active (GTK_COMBO_BOX (combo), GAMGI_MESA_WIRED - 1);
 
 entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_sampling");
 sprintf (token, "%d", GAMGI_CHEM_ORBITAL_POINTS);
@@ -1156,90 +1182,94 @@ renderer = gtk_cell_renderer_text_new ();
 gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (combo), renderer, FALSE);
 gtk_cell_layout_set_attributes (GTK_CELL_LAYOUT (combo), renderer, "text", 0, NULL);
 
-/*********************
- * Density, Sampling *
- *********************/
+/*****************
+ * 2nd, 3rd rows *
+ *****************/
 
 hbox_center = gtk_hbox_new (TRUE, 0);
 gtk_box_pack_start (GTK_BOX (vbox_top), hbox_center, FALSE, FALSE, 0);
 gtk_widget_show (hbox_center);
 
-hbox_left = gtk_hbox_new (FALSE, 20);
+hbox_left = gtk_hbox_new (FALSE, 15);
 gtk_box_pack_start (GTK_BOX (hbox_center), hbox_left, FALSE, FALSE, 0);
 gtk_widget_show (hbox_left);
 
+/*******************
+ * Density, Radius *
+ *******************/
+
+vbox_top_top = gtk_vbox_new (FALSE, 15);
+gtk_box_pack_start (GTK_BOX (hbox_left), vbox_top_top, FALSE, FALSE, 0);
+gtk_widget_show (vbox_top_top);
+
 hbox_left_left = gtk_hbox_new (FALSE, 5);
-gtk_box_pack_start (GTK_BOX (hbox_left), hbox_left_left, FALSE, FALSE, 0);
+gtk_box_pack_start (GTK_BOX (vbox_top_top), hbox_left_left, FALSE, FALSE, 0);
 gtk_widget_show (hbox_left_left);
 
-label = gtk_label_new ("Density");
-gtk_box_pack_start (GTK_BOX (hbox_left_left), label, FALSE, FALSE, 0);
-gtk_widget_show (label);
-
 entry = gtk_entry_new ();
-gtk_box_pack_start (GTK_BOX (hbox_left_left), entry, FALSE, FALSE, 0);
+gtk_box_pack_end (GTK_BOX (hbox_left_left), entry, FALSE, FALSE, 0);
 gtk_entry_set_width_chars (GTK_ENTRY (entry), GAMGI_GTK_CHAR_7);
 gtk_entry_set_max_length (GTK_ENTRY (entry), GAMGI_GTK_CHAR_7);
 g_object_set_data (G_OBJECT (dialog), "entry_density", entry);
 gtk_widget_show (entry);
 
-hbox_left_left = gtk_hbox_new (FALSE, 5);
-gtk_box_pack_start (GTK_BOX (hbox_left), hbox_left_left, FALSE, FALSE, 0);
-gtk_widget_show (hbox_left_left);
-
-label = gtk_label_new ("Sampling");
-gtk_box_pack_start (GTK_BOX (hbox_left_left), label, FALSE, FALSE, 0);
+label = gtk_label_new ("Density");
+gtk_box_pack_end (GTK_BOX (hbox_left_left), label, FALSE, FALSE, 0);
 gtk_widget_show (label);
 
-entry = gtk_entry_new ();
-gtk_box_pack_start (GTK_BOX (hbox_left_left), entry, FALSE, FALSE, 0);
-gtk_entry_set_width_chars (GTK_ENTRY (entry), GAMGI_GTK_CHAR_7);
-gtk_entry_set_max_length (GTK_ENTRY (entry), GAMGI_GTK_CHAR_7);
-g_object_set_data (G_OBJECT (dialog), "entry_sampling", entry);
-gtk_widget_show (entry);
-
-/****************
- * Radius, Seed *
- ****************/
-
-hbox_center = gtk_hbox_new (TRUE, 0);
-gtk_box_pack_start (GTK_BOX (vbox_top), hbox_center, FALSE, FALSE, 0);
-gtk_widget_show (hbox_center);
-
-hbox_left = gtk_hbox_new (FALSE, 20);
-gtk_box_pack_start (GTK_BOX (hbox_center), hbox_left, FALSE, FALSE, 0);
-gtk_widget_show (hbox_left);
-
 hbox_left_left = gtk_hbox_new (FALSE, 5);
-gtk_box_pack_start (GTK_BOX (hbox_left), hbox_left_left, FALSE, FALSE, 0);
+gtk_box_pack_start (GTK_BOX (vbox_top_top), hbox_left_left, FALSE, FALSE, 0);
 gtk_widget_show (hbox_left_left);
 
-label = gtk_label_new ("Radius");
-gtk_box_pack_start (GTK_BOX (hbox_left_left), label, FALSE, FALSE, 0);
-gtk_widget_show (label);
-
 entry = gtk_entry_new ();
-gtk_box_pack_start (GTK_BOX (hbox_left_left), entry, FALSE, FALSE, 0);
+gtk_box_pack_end (GTK_BOX (hbox_left_left), entry, FALSE, FALSE, 0);
 gtk_entry_set_width_chars (GTK_ENTRY (entry), GAMGI_GTK_CHAR_7);
 gtk_entry_set_max_length (GTK_ENTRY (entry), GAMGI_GTK_CHAR_7);
 g_object_set_data (G_OBJECT (dialog), "entry_radius", entry);
 gtk_widget_show (entry);
 
-hbox_left_left = gtk_hbox_new (FALSE, 5);
-gtk_box_pack_start (GTK_BOX (hbox_left), hbox_left_left, FALSE, FALSE, 0);
-gtk_widget_show (hbox_left_left);
-
-label = gtk_label_new (" Seed");
-gtk_box_pack_start (GTK_BOX (hbox_left_left), label, FALSE, FALSE, 0);
+label = gtk_label_new ("Radius");
+gtk_box_pack_end (GTK_BOX (hbox_left_left), label, FALSE, FALSE, 0);
 gtk_widget_show (label);
 
+/******************
+ * Sampling, Seed *
+ ******************/
+
+vbox_top_top = gtk_vbox_new (FALSE, 15);
+gtk_box_pack_start (GTK_BOX (hbox_left), vbox_top_top, FALSE, FALSE, 0);
+gtk_widget_show (vbox_top_top);
+
+hbox_left_left = gtk_hbox_new (FALSE, 5);
+gtk_box_pack_start (GTK_BOX (vbox_top_top), hbox_left_left, FALSE, FALSE, 0);
+gtk_widget_show (hbox_left_left);
+
 entry = gtk_entry_new ();
-gtk_box_pack_start (GTK_BOX (hbox_left_left), entry, FALSE, FALSE, 0);
+gtk_box_pack_end (GTK_BOX (hbox_left_left), entry, FALSE, FALSE, 0);
+gtk_entry_set_width_chars (GTK_ENTRY (entry), GAMGI_GTK_CHAR_7);
+gtk_entry_set_max_length (GTK_ENTRY (entry), GAMGI_GTK_CHAR_7);
+g_object_set_data (G_OBJECT (dialog), "entry_sampling", entry);
+gtk_widget_show (entry);
+
+label = gtk_label_new ("Sampling");
+gtk_box_pack_end (GTK_BOX (hbox_left_left), label, FALSE, FALSE, 0);
+gtk_widget_show (label);
+
+hbox_left_left = gtk_hbox_new (FALSE, 5);
+gtk_box_pack_start (GTK_BOX (vbox_top_top), hbox_left_left, FALSE, FALSE, 0);
+gtk_widget_show (hbox_left_left);
+
+entry = gtk_entry_new ();
+gtk_box_pack_end (GTK_BOX (hbox_left_left), entry, FALSE, FALSE, 0);
 gtk_entry_set_width_chars (GTK_ENTRY (entry), GAMGI_GTK_CHAR_7);
 gtk_entry_set_max_length (GTK_ENTRY (entry), GAMGI_GTK_CHAR_7);
 g_object_set_data (G_OBJECT (dialog), "entry_seed", entry);
 gtk_widget_show (entry);
 
+label = gtk_label_new ("Seed");
+gtk_box_pack_end (GTK_BOX (hbox_left_left), label, FALSE, FALSE, 0);
+gtk_widget_show (label);
+
 /***************
  * Volume page *
  ***************/
