@@ -127,10 +127,10 @@ if (orbital->style == GAMGI_MESA_SOLID)
   glEnable (GL_CULL_FACE);
   }
 
-if (dots[0] > 0)
+if (orbital->frame == TRUE)
   { glColor3f (orbital->frame_r, orbital->frame_g, orbital->frame_b);
     gamgi_mesa_render_lines (orbital->lines, orbital->points); }
-if (orbital->axes == TRUE)
+if (orbital->axes > 0.0)
   gamgi_mesa_axes_orbital (orbital, TRUE);
 
 /******************
