@@ -27,6 +27,7 @@
 #include "gamgi_gtk_orbital_create.h"
 #include "gamgi_gtk_orbital_copy.h"
 #include "gamgi_gtk_orbital_link.h"
+#include "gamgi_gtk_orbital_modify.h"
 #include "gamgi_gtk_orbital_remove.h"
 #include "gamgi_gtk_bond_create.h"
 #include "gamgi_gtk_bond_select.h"
@@ -645,6 +646,7 @@ switch (window_dialog->action)
   return TRUE;
 
   case GAMGI_GTK_ORBITAL_MODIFY:
+  gamgi_gtk_orbital_modify_press (window_mouse, event, x, y, window_dialog);
   return TRUE;
 
   case GAMGI_GTK_ORBITAL_REMOVE:
