@@ -279,24 +279,6 @@ for (i = -1; i <= 1; i++)
   }
 }
 
-static int static_cells_add (gamgi_atom *atom, int *cell, gamgi_rcp *rcp)
-{
-gamgi_slist **cells;
-int index;
-
-cells = rcp->cells;
-
-/********************************
- * add atom to cell linked list *
- ********************************/
-
-index = static_index (cell[0], cell[1], cell[2], rcp->slices);
-cells[index] = gamgi_engine_slist_add_start (cells[index]);
-cells[index]->data = atom;
-
-return index;
-}
-
 static void static_cells_locate (double *position, gamgi_rcp *rcp, int *cell)
 {
 double *width;
@@ -323,7 +305,7 @@ gamgi_rod **rods;
 gamgi_atom *atom;
 int cell[3];
 int n_atoms;
-int index, i;
+int i;
 
 rods = rcp->rods;
 n_atoms = rcp->n_atoms;
@@ -332,7 +314,6 @@ for (i = 0; i < n_atoms; i++)
   {
   atom = rods[i]->central;
   static_cells_locate (atom->position, rcp, cell);
-  index = static_cells_add (atom, cell, rcp);
   }
 
 }
@@ -1261,6 +1242,12 @@ double g_cn_average, g_cn_deviation;
 double t_cn_min, t_cn_max;
 double t_cn_average, t_cn_deviation;
 
+/**************************************
+ * no report is produced in List mode *
+ **************************************/
+
+if (text == NULL) return;
+
 /*********************
  * initialize buffer *
  *********************/
